pub enum ScalarDelta<T> {
Unchanged,
Changed(T),
}Expand description
This type exists as a workaround for the serde data model being unable to distinguish
between Some(None) and None in serialized bytes. It is, in nearly every respect,
Option<T>, just with some more semantic clarity. You may freely convert between this
and Option<T> using From::from or Into::into.
Variants
Unchanged
The value was not altered, use the old value.
Changed(T)
The value was altered, here is the new value.
Implementations
Sourceimpl<T> ScalarDelta<T>
impl<T> ScalarDelta<T>
Sourcepub fn is_unchanged(&self) -> bool
pub fn is_unchanged(&self) -> bool
Returns true if this contains no change.
Sourcepub fn is_changed(&self) -> bool
pub fn is_changed(&self) -> bool
Returns true if this contains a change.